#!/bin/bash

j2se_base="/usr/lib/jvm/java-1.6.0-sun/jre"
priority=3050

# alternative <program>
function program_alternative() {
    local program="$1"
    update-alternatives \
	--install "/usr/bin/$program" "$program" \
	"$j2se_base/bin/$program" "$priority" \
	--slave "/usr/share/man/man1/$program.1.gz" "$program.1.gz" \
	"$j2se_base/man/man1/$program.1.gz"
}

function select_alternative() {
    local program="$1"
    update-alternatives --config "$program"
}

program_alternative java
program_alternative java_vm
program_alternative javaws
program_alternative jcontrol
program_alternative keytool
program_alternative orbd
program_alternative pack200
program_alternative policytool
program_alternative rmid
program_alternative rmiregistry
program_alternative servertool
program_alternative tnameserv
program_alternative unpack200

# derive the architecture-specific 
# directory for the plugin
arch_dir="$(dpkg --print-architecture)"

# assemble the plugin path
plugin_dir="$j2se_base/plugin/$arch_dir"

# netscape
netscape_dir="/usr/lib/netscape/plugins-libc6"
[ -d "$netscape_dir" ] || install -d -m 755 "$netscape_dir"
update-alternatives \
    --install "$netscape_dir/libjavaplugin.so" \
	"netscape-javaplugin.so" \
    	"$plugin_dir/ns7-gcc29/libjavaplugin.so" "$priority"

# mozilla
mozilla_dir="/usr/lib/mozilla/plugins"
[ -d "$mozilla_dir" ] || install -d -m 755 "$mozilla_dir"
update-alternatives \
    --install "$mozilla_dir/libjavaplugin.so" \
	"mozilla-javaplugin.so" \
    	"$plugin_dir/ns7/libjavaplugin_oji.so" "$priority"

# old firefox / swiftfox
mozillafirefox_dir="/usr/lib/mozilla-firefox/plugins"
[ -d "$mozillafirefox_dir" ] || install -d -m 755 "$mozillafirefox_dir"
update-alternatives \
    --install "$mozillafirefox_dir/libjavaplugin.so" \
	"mozilla-firefox-javaplugin.so" \
    	"$plugin_dir/ns7/libjavaplugin_oji.so" "$priority"

# firefox
firefox_dir="/usr/lib/firefox/plugins"
[ -d "$firefox_dir" ] || install -d -m 755 "$firefox_dir"
update-alternatives \
    --install "$firefox_dir/libjavaplugin.so" \
	"firefox-javaplugin.so" \
    	"$plugin_dir/ns7/libjavaplugin_oji.so" "$priority"


# Remove obsolete javaplugin from users' homes
for user in $(ls /home); do 
	if [ -d "/home/$user/.mozilla/plugins" ]; then
		rm -f "/home/$user/.mozilla/plugins/libjavaplugin_oji.so"
	fi;
done

if [ -d "/root/.mozilla/plugins" ]; then
	rm -f "/root/.mozilla/plugins/libjavaplugin_oji.so"
fi

# menus
if [ -n "$(which update-menus)" ]; then
	update-menus;
fi

# mime
if [ -n "$(which update-mime)" ]; then
	update-mime;
fi
